==> rowan_python-2.1.11.tar.gz: rowan_python-2.1.11/examples/chai_paired_msa.py <==
import tarfile
from pathlib import Path

# from chai_lab.chai1 import run_inference
from stjames import MSAFormat

import rowan

# rowan.api_key = ""
example_fasta = (
    ">protein|name=example-protein\n"
    "VLSPADKTNVKAAWGKVGAHAGEYGAEALERMFLSFPTTKTYFPHFDLSHGSAQVKGHGKKVADALTNAVAHVDDMPNALSALSDLHAHKLRVDPVNFKLLSHCLLVTLAAHLPAEFTPAVHASLDKFLASVSTVLTSKYR\n"
    ">protein|name=example-protein-2\n"
    "VHLTPEEKSAVTALWGKVNVDEVGGEALGRLLVVYPWTQRFFESFGDLSTPDAVMGNPKVKAHGKKVLGAFSDGLAHLDNLKGTFATLSELHCDKLHVDPENFRLLGNVLVCVLAHHFGKEFTPPVQAAYQKVVAGVANALAHKYH\n"
)
fasta_path = Path("/tmp/input.fasta")
fasta_path.write_text(example_fasta)

output_dir = Path("/tmp/outputs")
msa_directory = Path("msa_directory")

msa_workflow = rowan.submit_msa_workflow(
    initial_protein_sequences=[
        "VLSPADKTNVKAAWGKVGAHAGEYGAEALERMFLSFPTTKTYFPHFDLSHGSAQVKGHGKKVADALTNAVAHVDDMPNALSALSDLHAHKLRVDPVNFKLLSHCLLVTLAAHLPAEFTPAVHASLDKFLASVSTVLTSKYR",
        "VHLTPEEKSAVTALWGKVNVDEVGGEALGRLLVVYPWTQRFFESFGDLSTPDAVMGNPKVKAHGKKVLGAFSDGLAHLDNLKGTFATLSELHCDKLHVDPENFRLLGNVLVCVLAHHFGKEFTPPVQAAYQKVVAGVANALAHKYH",
    ],
    output_formats=[MSAFormat.CHAI],
    name="CHAI Paired MSA Example",
)

msa_workflow.wait_for_result().fetch_latest(in_place=True)

msa_workflow.download_msa_files(MSAFormat.CHAI, path=msa_directory)

tar_path = next(msa_directory.glob("*.tar.gz"))
with tarfile.open(tar_path, "r") as tar_ref:
    tar_ref.extractall(msa_directory)

tar_path.unlink()


# run_inference(fasta_file=fasta_path,
#         output_dir=output_dir,
#         num_trunk_recycles=3,
#         num_diffn_timesteps=200,
#         seed=42,
#         device="cpu", # or "cuda:0"
#         use_esm_embeddings=True,
#         use_msa_server=False,
#         use_templates_server=False,
#         msa_directory=msa_directory)

==> rowan_python-2.1.15.tar.gz: rowan_python-2.1.15/examples/chai_paired_msa.py <==
import tarfile
from pathlib import Path

# from chai_lab.chai1 import run_inference
from stjames import MSAFormat

import rowan

# Set ROWAN_API_KEY environment variable to your API key or set rowan.api_key directly
# rowan.api_key = "rowan-sk..."

example_fasta = (
    ">protein|name=example-protein\n"
    "VLSPADKTNVKAAWGKVGAHAGEYGAEALERMFLSFPTTKTYFPHFDLSHGSAQVKGHGKKVADALTNAVAHVDDMPNALSALSDLHAHKLRVDPVNFKLLSHCLLVTLAAHLPAEFTPAVHASLDKFLASVSTVLTSKYR\n"
    ">protein|name=example-protein-2\n"
    "VHLTPEEKSAVTALWGKVNVDEVGGEALGRLLVVYPWTQRFFESFGDLSTPDAVMGNPKVKAHGKKVLGAFSDGLAHLDNLKGTFATLSELHCDKLHVDPENFRLLGNVLVCVLAHHFGKEFTPPVQAAYQKVVAGVANALAHKYH\n"
)
fasta_path = Path("/tmp/input.fasta")
fasta_path.write_text(example_fasta)

output_dir = Path("/tmp/outputs")
msa_directory = Path("msa_directory")

msa_workflow = rowan.submit_msa_workflow(
    initial_protein_sequences=[
        "VLSPADKTNVKAAWGKVGAHAGEYGAEALERMFLSFPTTKTYFPHFDLSHGSAQVKGHGKKVADALTNAVAHVDDMPNALSALSDLHAHKLRVDPVNFKLLSHCLLVTLAAHLPAEFTPAVHASLDKFLASVSTVLTSKYR",
        "VHLTPEEKSAVTALWGKVNVDEVGGEALGRLLVVYPWTQRFFESFGDLSTPDAVMGNPKVKAHGKKVLGAFSDGLAHLDNLKGTFATLSELHCDKLHVDPENFRLLGNVLVCVLAHHFGKEFTPPVQAAYQKVVAGVANALAHKYH",
    ],
    output_formats=[MSAFormat.CHAI],
    name="CHAI Paired MSA Example",
)

msa_workflow.wait_for_result().fetch_latest(in_place=True)

msa_workflow.download_msa_files(MSAFormat.CHAI, path=msa_directory)

tar_path = next(msa_directory.glob("*.tar.gz"))
with tarfile.open(tar_path, "r") as tar_ref:
    tar_ref.extractall(msa_directory)

tar_path.unlink()


# run_inference(fasta_file=fasta_path,
#         output_dir=output_dir,
#         num_trunk_recycles=3,
#         num_diffn_timesteps=200,
#         seed=42,
#         device="cpu", # or "cuda:0"
#         use_esm_embeddings=True,
#         use_msa_server=False,
#         use_templates_server=False,
#         msa_directory=msa_directory)
